@@ -15,6 +15,8 @@ lazy_static! {
             ("ADA/USDT", 10_f64),
             ("ALGO/USDT", 1_f64),
             ("ALICE/USDT", 0.1_f64),
+            ("API3/USDT", 0.1_f64),
+            ("ARPA/USDT", 10_f64),
             ("ATOM/USDT", 0.1_f64),
             ("AVAX/USDT", 0.1_f64),
             ("AXS/USDT", 0.1_f64),
@@ -26,11 +28,14 @@ lazy_static! {
             ("BTC/USDT", 0.001_f64),
             ("BTT/USDT", 1000_f64),
             ("C98/USDT", 1_f64),
+            ("CELO/USDT", 1_f64),
+            ("CELR/USDT", 10_f64),
             ("CHR/USDT", 1_f64),
             ("CHZ/USDT", 1_f64),
             ("COMP/USDT", 0.01_f64),
             ("CRO/USDT", 1_f64),
             ("CRV/USDT", 1_f64),
+            ("CTSI/USDT", 1_f64),
             ("DASH/USDT", 0.01_f64),
             ("DENT/USDT", 100_f64),
             ("DGB/USDT", 10_f64),
@@ -39,6 +44,7 @@ lazy_static! {
             ("DYDX/USDT", 0.1_f64),
             ("EGLD/USDT", 0.01_f64),
             ("ENJ/USDT", 1_f64),
+            ("ENS/USDT", 0.1_f64),
             ("EOS/USDT", 1_f64),
             ("ETC/USDT", 0.1_f64),
             ("ETH/USDT", 0.01_f64),
@@ -49,9 +55,11 @@ lazy_static! {
             ("GRT/USDT", 1_f64),
             ("HBAR/USDT", 10_f64),
             ("ICP/USDT", 0.01_f64),
+            ("IMX/USDT", 1_f64),
             ("IOST/USDT", 100_f64),
             ("IOTX/USDT", 10_f64),
             ("KEEP/USDT", 1_f64),
+            ("KNC/USDT", 1_f64),
             ("KSM/USDT", 0.01_f64),
             ("LINA/USDT", 10_f64),
             ("LINK/USDT", 0.1_f64),
@@ -64,6 +72,7 @@ lazy_static! {
             ("MKR/USDT", 0.001_f64),
             ("NEAR/USDT", 0.1_f64),
             ("NEO/USDT", 0.1_f64),
+            ("NFT/USDT", 100000_f64),
             ("OCEAN/USDT", 1_f64),
             ("OMG/USDT", 0.1_f64),
             ("ONE/USDT", 10_f64),
@@ -74,8 +83,10 @@ lazy_static! {
             ("RVN/USDT", 10_f64),
             ("SAND/USDT", 1_f64),
             ("SHIB/USDT", 100000_f64),
+            ("SLP/USDT", 10_f64),
             ("SNX/USDT", 0.1_f64),
             ("SOL/USDT", 0.1_f64),
+            ("SOS/USDT", 100000_f64),
             ("SUSHI/USDT", 1_f64),
             ("SXP/USDT", 1_f64),
             ("THETA/USDT", 0.1_f64),
